@@ -97,16 +97,18 @@
 #'   If \code{NULL} (default), \code{ncol} is computed internally based
 #'   on the number of rows of \code{conditions}.
 #' @param points Logical. Indicates if the original data points should be added
-#'   via \code{\link{geom_jitter}}. Default is \code{FALSE}. Can be controlled
-#'   globally via the \code{brms.plot_points} option. Note that only those data
-#'   points will be added that match the specified conditions defined in
-#'   \code{conditions}. For categorical predictors, the conditions have to match
-#'   exactly. For numeric predictors, argument \code{select_points} is used to
-#'   determine, which points do match a condition.
+#'   via \code{\link[ggplot2:geom_jitter]{geom_jitter}}. Default is
+#'   \code{FALSE}. Can be controlled globally via the \code{brms.plot_points}
+#'   option. Note that only those data points will be added that match the
+#'   specified conditions defined in \code{conditions}. For categorical
+#'   predictors, the conditions have to match exactly. For numeric predictors,
+#'   argument \code{select_points} is used to determine, which points do match a
+#'   condition.
 #' @param rug Logical. Indicates if a rug representation of predictor values
-#'   should be added via \code{\link{geom_rug}}. Default is \code{FALSE}.
-#'   Depends on \code{select_points} in the same way as \code{points} does. Can
-#'   be controlled globally via the \code{brms.plot_rug} option.
+#'   should be added via \code{\link[ggplot2:geom_rug]{geom_rug}}. Default is
+#'   \code{FALSE}. Depends on \code{select_points} in the same way as
+#'   \code{points} does. Can be controlled globally via the \code{brms.plot_rug}
+#'   option.
 #' @param mean Logical. Only relevant for spaghetti plots.
 #'   If \code{TRUE} (the default), display the mean regression
 #'   line on top of the regression lines for each sample.
@@ -118,30 +120,30 @@
 #'   Either \code{"contour"} or \code{"raster"}.
 #' @param line_args Only used in plots of continuous predictors:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_smooth}}.
+#'   \code{\link[ggplot2:geom_smooth]{geom_smooth}}.
 #' @param cat_args Only used in plots of categorical predictors:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_point}}.
+#'   \code{\link[ggplot2:geom_point]{geom_point}}.
 #' @param errorbar_args Only used in plots of categorical predictors:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_errorbar}}.
+#'   \code{\link[ggplot2:geom_errorbar]{geom_errorbar}}.
 #' @param surface_args Only used in surface plots:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_contour}} or
-#'   \code{\link{geom_raster}}
+#'   \code{\link[ggplot2:geom_contour]{geom_contour}} or
+#'   \code{\link[ggplot2:geom_raster]{geom_raster}}
 #'   (depending on argument \code{stype}).
 #' @param spaghetti_args Only used in spaghetti plots:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_smooth}}.
+#'   \code{\link[ggplot2:geom_smooth]{geom_smooth}}.
 #' @param point_args Only used if \code{points = TRUE}:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_jitter}}.
+#'   \code{\link[ggplot2:geom_jitter]{geom_jitter}}.
 #' @param rug_args Only used if \code{rug = TRUE}:
 #'   A named list of arguments passed to
-#'   \code{\link{geom_rug}}.
-#' @param facet_args Only used if if multiple condtions are provided:
+#'   \code{\link[ggplot2:geom_rug]{geom_rug}}.
+#' @param facet_args Only used if if multiple conditions are provided:
 #'   A named list of arguments passed to
-#'   \code{\link{facet_wrap}}.
+#'   \code{\link[ggplot2:facet_wrap]{facet_wrap}}.
 #'
 #' @return An object of class \code{'brms_conditional_effects'} which is a
 #'   named list with one data.frame per effect containing all information
@@ -154,7 +156,7 @@
 #'   rows).
 #'
 #'   The corresponding \code{plot} method returns a named
-#'   list of \code{\link{ggplot}} objects, which can be further
+#'   list of \code{\link[ggplot2:ggplot]{ggplot}} objects, which can be further
 #'   customized using the \pkg{ggplot2} package.
 #'
 #' @details When creating \code{conditional_effects} for a particular predictor
@@ -170,7 +172,8 @@
 #'
 #'   To fully change colors of the created plots, one has to amend both
 #'   \code{scale_colour} and \code{scale_fill}. See
-#'   \code{\link{scale_colour_grey}} or \code{\link{scale_colour_gradient}} for
+#'   \code{\link[ggplot2:scale_color_grey]{scale_colour_grey}} or
+#'   \code{\link[ggplot2:scale_color_gradient]{scale_colour_gradient}} for
 #'   more details.
 #'
 #' @examples
@@ -606,7 +609,8 @@ get_int_vars.mvbrmsterms <- function(x, ...) {
 
 #' @export
 get_int_vars.brmsterms <- function(x, ...) {
-  advars <- ulapply(rmNULL(x$adforms[c("trials", "thres", "vint")]), all_vars)
+  adterms <- c("trials", "thres", "vint")
+  advars <- ulapply(rmNULL(x$adforms[adterms]), all_vars)
   unique(c(advars, get_sp_vars(x, "mo")))
 }
 
