@@ -4,7 +4,8 @@ test_that("student distribution works correctly", {
   expect_equal(integrate(dstudent_t, -100, 100, df = 15, mu = 10, sigma = 5)$value, 1)
   expect_equal(dstudent_t(1, df = 10, mu = 0, sigma = 5), dt(1/5, df = 10)/5)
   expect_equal(pstudent_t(2, df = 20, mu = 2, sigma = 0.4), pt(0, df = 20))
-  expect_equal(qstudent_t(0.7, df = 5, mu = 2, sigma = 3), 2 + 3*qt(0.7, df = 5))
+  ps <- c(-1,0,0.7,1,1.5)
+  SW(expect_equal(qstudent_t(ps, df = 5, mu = 2, sigma = 3), 2 + 3*qt(ps, df = 5)))
   expect_equal(length(rstudent_t(10, df = 10, mu = rnorm(10), sigma = 1:10)), 10)
 })
 
@@ -65,6 +66,9 @@ test_that("skew_normal distribution functions run without errors", {
   res <- qskew_normal(p, mu = rnorm(n), sigma = 1:n,
                       alpha = 3, log.p = TRUE)
   expect_true(length(res) == n)
+  ps <- c(-1, 0, 0.5, 1, 1.5)
+  res <- SW(qskew_normal(ps))
+  expect_equal(res, c(NA, -Inf, 0, Inf, NA))
   res <- rskew_normal(n, mu = rnorm(n), sigma = 10, alpha = -4:5)
   expect_true(length(res) == n)
 })
@@ -91,6 +95,9 @@ test_that("frechet distribution functions run without errors", {
   expect_true(length(res) == n)
   q <- qfrechet(res, loc = loc, scale = 1:n, shape = 3)
   expect_equal(x, q)
+  ps <- c(-1, 0, 1, 1.5)
+  res <- SW(qfrechet(ps))
+  expect_equal(res, c(NA, 0, Inf, NA))
   res <- rfrechet(n, loc = loc, scale = 10, shape = 1:10)
   expect_true(length(res) == n)
 })
@@ -123,9 +130,12 @@ test_that("gen_extreme_value distribution functions run without errors", {
   x <- rgamma(n, 10, 3)
   res <- dgen_extreme_value(x, mu = 1, sigma = 2, xi = 1)
   expect_true(length(res) == n)
-  res <- pgen_extreme_value(x, mu = rnorm(n), sigma = 1:n, xi = 3)
+  mu <- rnorm(n)
+  res <- pgen_extreme_value(x, mu = mu, sigma = 1:n, xi = 3)
   expect_true(length(res) == n)
-  res <- rgen_extreme_value(n, mu = rnorm(n), sigma = 10, xi = 1:10)
+  q <- qgen_extreme_value(res, mu = mu, sigma = 1:n, xi = 3)
+  expect_equal(x, q)
+  res <- rgen_extreme_value(n, mu = mu, sigma = 10, xi = 1:10)
   expect_true(length(res) == n)
 })
 
